The NITF reserved extension header (sarpy.io.general.nitf_elements.res)
=======================================================================

.. automodule:: sarpy.io.general.nitf_elements.res
    :members:
    :show-inheritance:
    :inherited-members:
